/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_SRC_AUTH_BASIC_SMB_LM_MSNTAUTH_H
#define SQUID_SRC_AUTH_BASIC_SMB_LM_MSNTAUTH_H

extern int QueryServers(char *, char *);
extern void Check_forallowchange(void);

#endif /* SQUID_SRC_AUTH_BASIC_SMB_LM_MSNTAUTH_H */

